@@ -1,4 +1,4 @@
-__version__ = "2.1.0rc1"
+__version__: str = "2.6.2"
 
 ascii_art = f"""
   _   _                 _
@@ -13,4 +13,13 @@ ascii_art = f"""
       Version: {__version__}
 """
 
-print(ascii_art)
+if __name__ == "__main__":
+    print(ascii_art)
+
+    # Allow direct module execution to invoke the CLI
+    try:
+        from nexios.cli import cli
+
+        cli()
+    except ImportError:
+        print("CLI tools not available. Make sure Nexios is properly installed.")
